@@ -20,8 +20,8 @@
 
 #include <glib.h>
 
-#include <libtracker-common/tracker-ontologies.h>
-#include <libtracker-common/tracker-storage.h>
+#include <libtracker-common/tracker-common.h>
+#include <libtracker-sparql/tracker-sparql.h>
 
 #include "tracker-decorator-fs.h"
 #include "tracker-decorator-internal.h"
@@ -42,7 +42,7 @@
 typedef struct _TrackerDecoratorFSPrivate TrackerDecoratorFSPrivate;
 
 struct _TrackerDecoratorFSPrivate {
-	TrackerStorage *storage;
+	GVolumeMonitor *volume_monitor;
 };
 
 static GInitableIface *parent_initable_iface;
@@ -60,8 +60,8 @@ tracker_decorator_fs_finalize (GObject *object)
 
 	priv = TRACKER_DECORATOR_FS (object)->priv;
 
-	if (priv->storage)
-		g_object_unref (priv->storage);
+	if (priv->volume_monitor)
+		g_object_unref (priv->volume_monitor);
 
 	G_OBJECT_CLASS (tracker_decorator_fs_parent_class)->finalize (object);
 }
@@ -167,33 +167,57 @@ check_files (TrackerDecorator    *decorator,
 	g_string_free (query, TRUE);
 }
 
-static void
-mount_point_added_cb (TrackerStorage *storage,
-                      const gchar    *uuid,
-                      const gchar    *mount_point,
-                      const gchar    *mount_name,
-                      gboolean        removable,
-                      gboolean        optical,
-                      gpointer        user_data)
+static inline gchar *
+mount_point_get_uuid (GMount *mount)
 {
-	gchar *urn;
+	GVolume *volume;
+	gchar *uuid = NULL;
 
-	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
-	check_files (user_data, urn, TRUE, process_files_cb);
-	g_free (urn);
+	volume = g_mount_get_volume (mount);
+	if (volume) {
+		uuid = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UUID);
+		if (!uuid) {
+			gchar *mount_name;
+
+			mount_name = g_mount_get_name (mount);
+			uuid = g_compute_checksum_for_string (G_CHECKSUM_MD5, mount_name, -1);
+			g_free (mount_name);
+		}
+
+		g_object_unref (volume);
+	}
+
+	return uuid;
 }
 
 static void
-mount_point_removed_cb (TrackerStorage *storage,
-                        const gchar    *uuid,
-                        const gchar    *mount_point,
-                        gpointer        user_data)
+mount_point_added_cb (GVolumeMonitor *monitor,
+                      GMount         *mount,
+                      gpointer        user_data)
 {
+	gchar *uuid;
 	gchar *urn;
 
-	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+	uuid = mount_point_get_uuid (mount);
+	urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
+	check_files (user_data, urn, TRUE, process_files_cb);
+	g_free (urn);
+	g_free (uuid);
+}
+
+static void
+mount_point_removed_cb (GVolumeMonitor *monitor,
+                        GMount         *mount,
+                        gpointer        user_data)
+{
+	gchar *uuid;
+	gchar *urn;
+
+	uuid = mount_point_get_uuid (mount);
+	urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
 	check_files (user_data, urn, FALSE, remove_files_cb);
 	g_free (urn);
+	g_free (uuid);
 }
 
 static gboolean
@@ -204,13 +228,12 @@ tracker_decorator_fs_iface_init (GInitable     *initable,
 	TrackerDecoratorFSPrivate *priv;
 
 	priv = TRACKER_DECORATOR_FS (initable)->priv;
-	priv->storage = tracker_storage_new ();
 
-	g_signal_connect (priv->storage, "mount-point-added",
-	                  G_CALLBACK (mount_point_added_cb), initable);
-
-	g_signal_connect (priv->storage, "mount-point-removed",
-	                  G_CALLBACK (mount_point_removed_cb), initable);
+	priv->volume_monitor = g_volume_monitor_get ();
+	g_signal_connect_object (priv->volume_monitor, "mount-added",
+	                         G_CALLBACK (mount_point_added_cb), initable, 0);
+	g_signal_connect_object (priv->volume_monitor, "mount-removed",
+	                         G_CALLBACK (mount_point_removed_cb), initable, 0);
 
 	return parent_initable_iface->init (initable, cancellable, error);
 }
