@@ -685,7 +685,8 @@ sparql_contents_query_cb (GObject      *object,
 
 static gchar *
 sparql_contents_compose_query (GFile **directories,
-                               guint   n_dirs)
+                               guint   n_dirs,
+                               GQueue *filter)
 {
 	GString *str;
 	gchar *uri;
@@ -695,6 +696,9 @@ sparql_contents_compose_query (GFile **directories,
 			    " ?u nfo:belongsToContainer ?f . ?f nie:url ?url ."
 			    " FILTER (?url IN (");
 	for (i = 0; i < n_dirs; i++) {
+		if (g_queue_find (filter, directories[i]))
+			continue;
+
 		if (i != 0)
 			g_string_append_c (str, ',');
 
@@ -711,13 +715,14 @@ sparql_contents_compose_query (GFile **directories,
 static void
 sparql_contents_query_start (TrackerFileNotifier  *notifier,
                              GFile               **directories,
-                             guint                 n_dirs)
+                             guint                 n_dirs,
+                             GQueue               *filter)
 {
 	TrackerFileNotifierPrivate *priv;
 	gchar *sparql;
 
 	priv = notifier->priv;
-	sparql = sparql_contents_compose_query (directories, n_dirs);
+	sparql = sparql_contents_compose_query (directories, n_dirs, filter);
 	tracker_sparql_connection_query_async (priv->connection,
 	                                       sparql,
 	                                       priv->cancellable,
@@ -757,7 +762,8 @@ sparql_files_query_cb (GObject      *object,
 		/* Updated directories have been found, check for deleted contents in those */
 		sparql_contents_query_start (notifier,
 		                             (GFile**) priv->current_index_root->updated_dirs->pdata,
-		                             priv->current_index_root->updated_dirs->len);
+		                             priv->current_index_root->updated_dirs->len,
+		                             priv->current_index_root->pending_dirs);
 		g_ptr_array_set_size (priv->current_index_root->updated_dirs, 0);
 	} else {
 		finish_current_directory (notifier);
@@ -1666,6 +1672,7 @@ tracker_file_notifier_get_file_iri (TrackerFileNotifier *notifier,
 	TrackerFileNotifierPrivate *priv;
 	GFile *canonical;
 	gchar *iri = NULL;
+	gboolean found;
 
 	g_return_val_if_fail (TRACKER_IS_FILE_NOTIFIER (notifier), NULL);
 	g_return_val_if_fail (G_IS_FILE (file), NULL);
@@ -1679,9 +1686,21 @@ tracker_file_notifier_get_file_iri (TrackerFileNotifier *notifier,
 		return NULL;
 	}
 
-	iri = tracker_file_system_get_property (priv->file_system,
-	                                        canonical,
-	                                        quark_property_iri);
+	found = tracker_file_system_get_property_full (priv->file_system,
+	                                               canonical,
+	                                               quark_property_iri,
+	                                               (gpointer *) &iri);
+
+	if (found && !iri) {
+		/* NULL here mean the file iri was "invalidated", the file
+		 * was inserted by a previous event, so it has an unknown iri,
+		 * and further updates are keeping the file object alive.
+		 *
+		 * When these updates are processed, they'll need fetching the
+		 * file IRI again, so we force here extraction for these cases.
+		 */
+		force = TRUE;
+	}
 
 	if (!iri && force) {
 		TrackerSparqlCursor *cursor;
@@ -1705,3 +1724,29 @@ tracker_file_notifier_get_file_iri (TrackerFileNotifier *notifier,
 
 	return iri;
 }
+
+void
+tracker_file_notifier_invalidate_file_iri (TrackerFileNotifier *notifier,
+                                           GFile               *file)
+{
+	TrackerFileNotifierPrivate *priv;
+	GFile *canonical;
+
+	g_return_val_if_fail (TRACKER_IS_FILE_NOTIFIER (notifier), NULL);
+	g_return_val_if_fail (G_IS_FILE (file), NULL);
+
+	priv = notifier->priv;
+	canonical = tracker_file_system_get_file (priv->file_system,
+	                                          file,
+	                                          G_FILE_TYPE_REGULAR,
+	                                          NULL);
+	if (!canonical) {
+		return;
+	}
+
+	/* Set a NULL iri, so we make sure to look it up afterwards */
+	tracker_file_system_set_property (priv->file_system,
+	                                  canonical,
+	                                  quark_property_iri,
+	                                  NULL);
+}
