@@ -90,6 +90,9 @@ const gchar * tracker_file_notifier_get_file_iri (TrackerFileNotifier     *notif
                                                   GFile                   *file,
                                                   gboolean                 force);
 
+void          tracker_file_notifier_invalidate_file_iri (TrackerFileNotifier *notifier,
+                                                         GFile               *file);
+
 G_END_DECLS
 
 #endif /* __TRACKER_FILE_SYSTEM_H__ */
